@@ -86,6 +86,10 @@ namespace Molsketch {
     initialize(position, element, implicitHydrogens);
   }
 
+  Atom::Atom(const Core::Position &position, const QString &element)
+  : Atom(QPointF(position.getX(), position.getY()), element)
+  {}
+
   Atom::Atom(const Atom &other)
     : graphicsItem (other)
   { // TODO unit test copy constructor
@@ -131,12 +135,6 @@ namespace Molsketch {
     setZValue(3);
     setShapeType(Rectangle);
 
-    MolScene *molScene = qobject_cast<MolScene*>(scene());
-
-    if (molScene) {
-      setColor (molScene->settings()->defaultColor()->get());
-    }
-    else setColor (QColor (0, 0, 0));
     // Enabling hovereffects
     setAcceptHoverEvents(true) ;
 
